@@ -220,4 +220,4 @@ def logger(logFile, logMsg, printLogMsg):
 
     if(printLogMsg is True):
         print(logMsg)
-    logFile.write('\n' + str((sys.argv[0]).rsplit('/', 1)) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
\ No newline at end of file
+    logFile.write('\n' + str((sys.argv[0]).rsplit('/', 1))[-1]) + " " + str(times()['day'][:3]) + " " + str(times()['month'][:3]) + " " + str(times()['date']) + " " + str(time.tzname[0]) + " " + str(times()['year']) + " - " + str(logMsg) + "\n")
\ No newline at end of file
